@@ -11,7 +11,7 @@ from astra_assistants.tools.tool_interface import ToolInterface
 logger = logging.getLogger(__name__)
 
 class AssistantManager:
-    def __init__(self, instructions: str, tools: List[ToolInterface], model: str = "gpt-4o", name: str = "managed_assistant"):
+    def __init__(self, instructions: str, tools: List[ToolInterface], model: str = "gpt-4o", name: str = "managed_assistant", thread_id: str = None, thread: str = None):
 
         self.client = patch(OpenAI())
         self.model = model
@@ -20,7 +20,14 @@ class AssistantManager:
         self.name = name
 
         self.assistant = self.create_assistant()
-        self.thread = self.create_thread()
+
+        if thread_id is None and thread is None:
+            self.thread = self.create_thread()
+        elif thread is not None:
+            self.thread = thread
+        elif thread_id is not None:
+            self.thread = self.client.beta.threads.retrieve(thread_id)
+
         print(f'assistant {self.assistant}')
         print(f'thread {self.thread}')
 
@@ -54,16 +61,21 @@ class AssistantManager:
         print("Thread generated:", thread)
         return thread
 
-    async def run_thread(self, tool, content) -> ToolOutput:
+    async def run_thread(self, tool, content, thread_id: str = None, thread = None) -> ToolOutput:
+        if thread_id is not None:
+            thread = self.client.beta.threads.retrieve(thread_id)
+        elif thread is None:
+            thread = self.thread
+
         assistant = self.assistant
         event_handler = AstraEventHandler(self.client)
         event_handler.register_tool(tool)
         try:
             self.client.beta.threads.messages.create(
-                thread_id=self.thread.id, role="user", content=content
+                thread_id=thread.id, role="user", content=content
             )
             with self.client.beta.threads.runs.create_and_stream(
-                    thread_id=self.thread.id,
+                    thread_id=thread.id,
                     assistant_id=assistant.id,
                     event_handler=event_handler,
                     tool_choice=tool.tool_choice_object(),
@@ -75,10 +87,12 @@ class AssistantManager:
                 for part in stream.text_deltas:
                     text += part
 
-            tool_call_results = event_handler.tool_call_results
+                tool_call_results = event_handler.tool_call_results
+                tool_call_results['text'] = text
+                tool_call_results['error'] = event_handler.error
 
-            print(tool_call_results)
-            return tool_call_results
+                print(tool_call_results)
+                return tool_call_results
         except Exception as e:
             print(e)
             raise e
\ No newline at end of file
